"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextClsStoreMap = void 0;
/**
 * This static class can be used to save the CLS store in a WeakMap based on the ExecutionContext
 * or any object that is passed to the `setByRawContext` method.
 *
 * It is used internally by the `ClsMiddleware`, `ClsInterceptor` and `ClsGuard` to prevent
 * instantiating the context multiple times for the same request.
 *
 * It can also be used as an escape hatch to retrieve the CLS store based on the ExecutionContext
 * or the "raw context" when the ExecutionContext is not available.
 * * For HTTP, it is the Request (@Req) object
 * * For WS, it is the data object
 * * For RPC (microservices), it is the RpcContext (@Ctx) object
 * * For GraphQL, it is the GqlContext object
 */
class ContextClsStoreMap {
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    constructor() { }
    static set(context, value) {
        const ctx = this.getContextByType(context);
        this.contextMap.set(ctx, value);
    }
    static get(context) {
        const ctx = this.getContextByType(context);
        return this.contextMap.get(ctx);
    }
    static setByRaw(ctx, value) {
        this.contextMap.set(ctx, value);
    }
    static getByRaw(ctx) {
        return this.contextMap.get(ctx);
    }
    static getContextByType(context) {
        switch (context.getType()) {
            case 'http':
                return context.switchToHttp().getRequest();
            case 'ws':
                return context.switchToWs().getData();
            case 'rpc':
                return context.switchToRpc().getContext();
            case 'graphql':
                // As per the GqlExecutionContext, the context is the second argument
                return context.getArgByIndex(2);
            default:
                return {};
        }
    }
}
exports.ContextClsStoreMap = ContextClsStoreMap;
ContextClsStoreMap.contextMap = new WeakMap();
//# sourceMappingURL=context-cls-store-map.js.map